==> datadog-cdk-constructs-0.6.0.tar.gz: package/lib/common/interfaces.d.ts <==
/**
 * @stability stable
 */
export interface DatadogProps {
    /**
     * @stability stable
     */
    readonly pythonLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly nodeLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly extensionLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly addLayers?: boolean;
    /**
     * @stability stable
     */
    readonly forwarderArn?: string;
    /**
     * @stability stable
     */
    readonly flushMetricsToLogs?: boolean;
    /**
     * @stability stable
     */
    readonly site?: string;
    /**
     * @stability stable
     */
    readonly apiKey?: string;
    /**
     * @stability stable
     */
    readonly apiKeySecretArn?: string;
    /**
     * @stability stable
     */
    readonly apiKmsKey?: string;
    /**
     * @stability stable
     */
    readonly enableDatadogTracing?: boolean;
    /**
     * @stability stable
     */
    readonly injectLogContext?: boolean;
    /**
     * @stability stable
     */
    readonly logLevel?: string;
    /**
     * @stability stable
     */
    readonly enableDatadogLogs?: boolean;
    /**
     * @stability stable
     */
    readonly captureLambdaPayload?: boolean;
}
/**
 * @stability stable
 */
export interface DatadogStrictProps {
    /**
     * @stability stable
     */
    readonly addLayers: boolean;
    /**
     * @stability stable
     */
    readonly enableDatadogLogs: boolean;
    /**
     * @stability stable
     */
    readonly captureLambdaPayload: boolean;
    /**
     * @stability stable
     */
    readonly injectLogContext: boolean;
    /**
     * @stability stable
     */
    readonly enableDatadogTracing: boolean;
    /**
     * @stability stable
     */
    readonly pythonLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly nodeLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly extensionLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly forwarderArn?: string;
    /**
     * @stability stable
     */
    readonly flushMetricsToLogs?: boolean;
    /**
     * @stability stable
     */
    readonly site?: string;
    /**
     * @stability stable
     */
    readonly apiKey?: string;
    /**
     * @stability stable
     */
    readonly apiKeySecretArn?: string;
    /**
     * @stability stable
     */
    readonly apiKmsKey?: string;
    /**
     * @stability stable
     */
    readonly logLevel?: string;
}
/**
 * @stability stable
 */
export interface Runtime {
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface Node {
    /**
     * @stability stable
     */
    readonly defaultChild: any;
}
/**
 * @stability stable
 */
export interface ILambdaFunction {
    /**
     * @stability stable
     */
    runtime: Runtime;
    /**
     * @stability stable
     */
    node: Node;
    /**
     * @stability stable
     */
    addEnvironment(ey: string, value: string, options?: Record<string, unknown>): void;
}

==> datadog-cdk-constructs-0.7.1.tar.gz: package/lib/common/interfaces.d.ts <==
/**
 * @stability stable
 */
export interface DatadogProps {
    /**
     * @stability stable
     */
    readonly pythonLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly nodeLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly extensionLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly addLayers?: boolean;
    /**
     * @stability stable
     */
    readonly forwarderArn?: string;
    /**
     * @stability stable
     */
    readonly flushMetricsToLogs?: boolean;
    /**
     * @stability stable
     */
    readonly site?: string;
    /**
     * @stability stable
     */
    readonly apiKey?: string;
    /**
     * @stability stable
     */
    readonly apiKeySecretArn?: string;
    /**
     * @stability stable
     */
    readonly apiKmsKey?: string;
    /**
     * @stability stable
     */
    readonly enableDatadogTracing?: boolean;
    /**
     * @stability stable
     */
    readonly injectLogContext?: boolean;
    /**
     * @stability stable
     */
    readonly logLevel?: string;
    /**
     * @stability stable
     */
    readonly enableDatadogLogs?: boolean;
    /**
     * @stability stable
     */
    readonly captureLambdaPayload?: boolean;
    /**
     * @stability stable
     */
    readonly env?: string;
    /**
     * @stability stable
     */
    readonly service?: string;
    /**
     * @stability stable
     */
    readonly version?: string;
    /**
     * @stability stable
     */
    readonly tags?: string;
}
/**
 * @stability stable
 */
export interface DatadogStrictProps {
    /**
     * @stability stable
     */
    readonly addLayers: boolean;
    /**
     * @stability stable
     */
    readonly enableDatadogLogs: boolean;
    /**
     * @stability stable
     */
    readonly captureLambdaPayload: boolean;
    /**
     * @stability stable
     */
    readonly injectLogContext: boolean;
    /**
     * @stability stable
     */
    readonly enableDatadogTracing: boolean;
    /**
     * @stability stable
     */
    readonly pythonLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly nodeLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly extensionLayerVersion?: number;
    /**
     * @stability stable
     */
    readonly forwarderArn?: string;
    /**
     * @stability stable
     */
    readonly flushMetricsToLogs?: boolean;
    /**
     * @stability stable
     */
    readonly site?: string;
    /**
     * @stability stable
     */
    readonly apiKey?: string;
    /**
     * @stability stable
     */
    readonly apiKeySecretArn?: string;
    /**
     * @stability stable
     */
    readonly apiKmsKey?: string;
    /**
     * @stability stable
     */
    readonly logLevel?: string;
}
/**
 * @stability stable
 */
export interface Runtime {
    /**
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface Node {
    /**
     * @stability stable
     */
    readonly defaultChild: any;
}
/**
 * @stability stable
 */
export interface ILambdaFunction {
    /**
     * @stability stable
     */
    runtime: Runtime;
    /**
     * @stability stable
     */
    node: Node;
    /**
     * @stability stable
     */
    addEnvironment(key: string, value: string, options?: Record<string, unknown>): void;
}
